@@ -1,5 +1,5 @@
 /*****************************************************************
-* unit:    doublelists             release 0.6                   *
+* unit:    doublelists             release 0.7                   *
 * purpose: general manipulation with array of couples of strings *
 * Licency: GPL or LGPL                                           *
 * Copyright: (c) 1998-2023 Jaroslav Fojtik                       *
@@ -70,7 +70,7 @@ switch(j)
    case 0:return(str);
    case 1:if(flipped)
 		{
-		str=strstr(str,"\1");
+		str=strchr(str,'\1');
 		}
 	   else {
 		str+=strlen(str);
@@ -94,7 +94,7 @@ switch(j)
    case 0:return(str);
    case 1:if(flipped)
 		{
-		str=strstr(str,"\1");
+		str=strchr(str,'\1');
 		}
 	   else {
 		str+=strlen(str);
