@@ -1,8 +1,8 @@
 /***************************************************
-* unit:    strings           release 0.26          *
+* unit:    strings           release 0.27          *
 * purpose: general manipulation with text strings  *
 * Licency: GPL or LGPL                             *
-* Copyright: (c) 1998-2022 Jaroslav Fojtik         *
+* Copyright: (c) 1998-2025 Jaroslav Fojtik         *
 ****************************************************/
 /* NOTE: strings.h clashes with standard headers, thus stringa.h */
 #ifndef __Stringa_h
@@ -194,7 +194,7 @@ public:   string(void)				{size=maxlen=0;ch=0;};
 	  friend void erase(string &s)	{s.erase();};
 
 //Overloading of well known C string functions
-	  friend temp_string del(const string &s,int from, int len=1);
+	  friend temp_string del(const string &s,int from, int len);
 	  friend temp_string insert(const string &s,const string &s2,int position);
 	  inline char *strchr(const string &s1,char c) {return(StrChr(s1.ch,c));};
 	  inline char *strstr(const string &s1,const string &s2) {return(StrStr(s1.ch,s2.ch));};
@@ -221,6 +221,8 @@ public:   string(void)				{size=maxlen=0;ch=0;};
           int cat_printf(const char* format, ...);
 	  };
 
+temp_string del(const string &s,int from, int len=1);
+
 
 #ifdef USE_TEMP_STRINGS
 /// Internal speedup class - do not use it! When string is constructed from
