@@ -1,3 +1,5 @@
+#ifndef __SWAP_BITS_XLAT__
+#define __SWAP_BITS_XLAT__
 
 
 #ifdef __cplusplus
@@ -8,3 +10,6 @@ extern const unsigned char swap_bits2_xlat[256];
 #ifdef __cplusplus
 }
 #endif
+
+
+#endif
