@@ -1,8 +1,8 @@
 /*******************************************************
-* unit:    lists             release 0.15              *
+* unit:    lists             release 0.16              *
 * purpose: general manipulation with array of strings  *
 * Licency: GPL or LGPL                                 *
-* Copyright: (c) 1998-2019 Jaroslav Fojtik             *
+* Copyright: (c) 1998-2023 Jaroslav Fojtik             *
 ********************************************************/
 #include <stdlib.h>
 #include <string.h>
@@ -158,18 +158,24 @@ return(*this);
 /*This operator adds one item to the list.*/
 int list::operator+=(const char *str)
 {
- if(number>=numalloc || pstr==NULL)
-	{
-        void *cpstr = (char **)realloc(pstr,++numalloc*sizeof(char *));
-	if(cpstr==NULL)
+ if(pstr==NULL)		// The list is empty.
+    {
+    *this = str;
+    return number-1;	// returns 0, on alloc failure returns -1
+    }
+
+ if(number>=numalloc)
+    {
+    void *cpstr = (char **)realloc(pstr,++numalloc*sizeof(char *));
+    if(cpstr==NULL)
 		{                
                 free(pstr); pstr=NULL;
 		number=numalloc=0;
 		RaiseError(ListsId|No_Memory,this);	//Memory Exhausted
 		return(-1);
 		}
-        pstr = (char**)cpstr;
-	}
+    pstr = (char**)cpstr;
+    }
 
  if(str)
    {
@@ -333,10 +339,17 @@ int list::operator|=(const char *str)
 {
 int i;
 
+if(pstr==NULL)		// The list is empty.
+   {
+   *this = str;
+   return number-1;	// returns 0, on alloc failure returns -1
+   }
+
 if((i=(str IN *this))>0) return(i-1);
 
 #ifndef OptSize
- if(number>=numalloc || pstr==NULL)
+
+ if(number>=numalloc)
 	{
         void *cpstr = realloc(pstr,++numalloc*sizeof(char *));
 	if(cpstr==NULL)
@@ -745,18 +758,23 @@ return(r);
 
 
 #ifdef Streams
+
+#ifndef IOSTREAM_H_ONLY
+ using namespace std;
+#endif
+
+
 ostream &operator<<(ostream &xout, const list &l)
 {
 int i;
 
-  xout<<"{";
+  xout << '{';
   for(i=0;i<length(l);i++)
 	{
 	if(i>0) xout<<",";
 	xout<<"\""<<(l[i]==NULL?"NULL":l[i])<<"\"";
 	}
-  xout<<"}";
-return xout;
+return xout << '}';
 }
 
 #endif
