@@ -1,5 +1,5 @@
 /*************************************************************
- * Unit:    raster            release 0.33                   *
+ * Unit:    raster            release 0.34                   *
  * Purpose: General manipulation n dimensional matrices      *
  *          n = 1, 2 and 3.			             *
  * Modul:   raster.cc                                        *
@@ -540,19 +540,19 @@ int i;
   }
   else
   {
-    uint8_t *N_Buffer8Bit = (uint8_t *)Data1D;
-    uint8_t Mask;
-    uint32_t Half = 1 << (i-1);
-    i = 0;
-    while(i<Size1D)
-    {    
-      *N_Buffer8Bit = 0;
-      for(Mask=0x80; Mask!=0; Mask>>=1)
+    uint8_t *N_Buffer8Bit = (uint8_t *)Data1D - 1;
+    const uint32_t Half = 1 << (i-1);
+    uint8_t Mask = 0;
+    for(unsigned x=0; x<Size1D; x++)
+    {
+      Mask >>= 1;
+      if(Mask == 0)
       {
-        if(R1.GetValue1D(i)>=Half) *N_Buffer8Bit |= Mask;
-        if(++i>=Size1D) return;
+        ++N_Buffer8Bit;
+        *N_Buffer8Bit = 0;
+        Mask = 0x80;
       }
-      N_Buffer8Bit++;
+      if(R1.GetValue1D(x)>=Half) *N_Buffer8Bit|=Mask;
     }
   }
 }
