@@ -1,5 +1,5 @@
 /*************************************************************************
-* unit:    struct            release 0.17                                *
+* unit:    struct            release 0.18                                *
 *   struct.c - Provides some big and little endian abstraction functions,
 *	      for manipulating with structures.
 * Licency: GPL or LGPL                                                   *
@@ -112,7 +112,7 @@ uint8_t b[4];
 #endif
 
 
-#ifndef RdQWORD_LoEnd
+#if !defined(RdQWORD_LoEnd) && (defined(uint64_t_defined) || defined(LO_ENDIAN) || defined(HI_ENDIAN))
 /* Read a double word from binary file in a LowEndian Format into a current endian.
  * parameters: FILE  *f :  binary input file
  * return:     QWORD *num : readed double word  */
@@ -154,12 +154,10 @@ int RdWORD_HiEnd(uint16_t *num, FILE *f)
 int ret = fread(num,1,2,f);
   *num = ((*num & 0xFF)<<8) | ((*num & 0xFF00)>>8);
 return ret;
-#endif
+#else
 #ifdef HI_ENDIAN
   return(fread(num,1,2,f));
-#endif
-#if !defined(LO_ENDIAN) && !defined(HI_ENDIAN)
-		//endian invariant
+#else		//endian invariant
 unsigned char b[2];
   const int i = fread(b,1,2,f);
   if(i>0) {*num=(uint16_t)b[0] * 256l;
@@ -167,6 +165,7 @@ unsigned char b[2];
   }
   return i;
 #endif
+#endif
 }
 #endif
 
@@ -199,7 +198,7 @@ uint8_t b[4];
 #endif
 
 
-#ifndef RdQWORD_HiEnd
+#if !defined(RdQWORD_HiEnd) && (defined(uint64_t_defined) || defined(LO_ENDIAN) || defined(HI_ENDIAN))
 /* Read a quad word from binary file in a HighEndian Format
  * parameters: FILE  *f :  binary input file
  * return:     uint32_t *num : readed double word  */
@@ -329,8 +328,7 @@ uint8_t b[4];
 #endif
 
 
-
-#ifndef WrQWORD_HiEnd
+#if !defined(WrQWORD_HiEnd) && (defined(uint64_t_defined) || defined(LO_ENDIAN) || defined(HI_ENDIAN))
 /* Write a quad word to the binary file in a HiEndian Format
  * parameters: FILE  *f :  binary input file
  *             uint32_t num : double word to be written */
@@ -359,7 +357,7 @@ uint8_t b[8];
 #endif
 
 
-#ifndef WrQWORD_LoEnd
+#if !defined(WrQWORD_LoEnd) && (defined(uint64_t_defined) || defined(LO_ENDIAN) || defined(HI_ENDIAN))
 /* Write a quad word to the binary file in a LowEndian Format
  * parameters: FILE  *f :  binary input file
  *             uint32_t num : double word to be written */
