@@ -523,7 +523,7 @@ FILE *F;
 codepage internal;
 codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1256, cp1276, cpkam,
          cpwp4a, cpwp5, cpwp5_cz, cpwp6,
-	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4, iso_8859_5, iso_8859_6,
+	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4, iso_8859_5, iso_8859_6, iso_8859_7,
          unicode,koi8cs,koi8r,
 	 mtef2,
          MAC_ROMAN;
@@ -630,6 +630,8 @@ int TimeoutCounter;
  if(iso_8859_5.name) {free(iso_8859_5.name);iso_8859_5.name=strdup("iso_8859_5");}
  LoadCodePage("is8859_6",iso_8859_6,0);
  if(iso_8859_6.name) {free(iso_8859_6.name);iso_8859_6.name=strdup("iso_8859_6");}
+ LoadCodePage("is8859_7",iso_8859_7,0);
+ if(iso_8859_7.name) {free(iso_8859_7.name);iso_8859_7.name=strdup("iso_8859_7");}
 
 
  //if(heapcheck()<=0)
@@ -705,6 +707,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
  BuildTranslator(iso_8859_4,internal,F);	iso_8859_4.Erase();
  BuildTranslator(iso_8859_5,internal,F);	iso_8859_5.Erase();
  BuildTranslator(iso_8859_6,internal,F);	iso_8859_6.Erase();
+ BuildTranslator(iso_8859_7,internal,F);	iso_8859_7.Erase();
 
  BuildTranslator(cp852,internal,F);		cp852.Erase();
  BuildTranslator(cp1250,internal,F);		cp1250.Erase();
