@@ -15,7 +15,7 @@
 #include "stringa.h"
 
 
-#define RAS_IMG_VERSION (0x200 | 78)
+#define RAS_IMG_VERSION (0x200 | 79)
 
 // Definition of errors while Loading/Saving File(s)
 #define ErrOK		  0
@@ -58,6 +58,13 @@ public:
 };
 
 
+class PropertyItemInt: public PropertyItem
+{
+public:
+  PropertyItemInt(const char *NewName, int Value): PropertyItem(NewName,sizeof(int)) {*(int*)Data=Value;}
+};
+
+
 class PropertyList
 {
 public:
