@@ -1,9 +1,9 @@
 /***************************************************************************
- * Unit:    raster            release 0.32                                 *
+ * Unit:    raster            release 0.33                                 *
  * Purpose: Prototypes for low level pixelbuff operations.                 *
  * Modul:   img_tool.h                                                     *
  * Licency: GPL or LGPL                                                    *
- * Copyright: (c) 1998-2024 Jaroslav Fojtik                                *
+ * Copyright: (c) 1998-2025 Jaroslav Fojtik                                *
  ***************************************************************************/
 #ifndef _IMG_TOOL_H
 #define _IMG_TOOL_H
@@ -52,6 +52,8 @@ void V210_RGB(uint8_t *out, const uint32_t *in, int LoopCount);
 void V210_Gray24(uint8_t *out, const uint32_t *in, int LoopCount);
 void V210_Gray8(uint8_t *out, const uint32_t *in, int LoopCount);
 
+void AbsCopy_u32(uint32_t *Out, uint32_t *In1, uint32_t *In2, int SizeX);
+void AbsHor_u32(uint32_t *Out, uint32_t *In, int SizeX);
 void Gaus1D_u32(uint32_t *line, int sizex, uint16_t times);
 void GausVer1_u32(uint32_t *Out, const uint32_t *L1, const uint32_t *L2, const uint32_t *L3 , int sizex);
 void DiffHor1_u32(uint32_t *Out, const uint32_t *In , int SizeX);
