@@ -182,10 +182,11 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 	NULL,
  #endif
  #if SupportFITS>=3
-	SavePictureFITS);
+	SavePictureFITS,
  #else
-	NULL);
+	NULL,
  #endif
+        NULL,FILE_FORMAT_DUPLICATE);
 #endif
 
 
@@ -197,10 +198,11 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 	NULL,
  #endif
  #if SupportGIF>=3
-	SavePictureGIF);
+	SavePictureGIF,
 #else
-	NULL);
+	NULL,
 #endif
+        NULL, FILE_FORMAT_256_COLORS);
 #endif
 
 
@@ -269,7 +271,7 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 	NULL,
  #endif
 	NULL,
-        "r4");
+        "r4", FILE_FORMAT_DUPLICATE);
 
 #endif
 
@@ -346,6 +348,21 @@ TImageFileHandler HANDLER_PPM(".PPM",
 #endif
 
 
+#ifdef SupportQOI
+ ImplementReader(QOI,".QOI")
+#if SupportQOI>=4 || SupportQOI==2
+	LoadPictureQOI,
+#else
+	NULL,
+#endif
+#if SupportQOI>=3
+	SavePictureQOI);
+#else
+	NULL);
+#endif
+#endif
+
+
 #ifdef SupportRAS_SUN
  ImplementReader(RAS_SUN, ".RAS")
  #if SupportRAS_SUN>=4 || SupportRAS_SUN==2
@@ -408,13 +425,13 @@ TImageFileHandler HANDLER_PPM(".PPM",
 #if SupportTGA>=4 || SupportTGA==2
  ImplementReader(ICB,".ICB")
 	LoadPictureTGA,
-	NULL);
+	NULL, NULL, FILE_FORMAT_DUPLICATE);
  ImplementReader(VDA,".VDA")
 	LoadPictureTGA,
-	NULL);
+	NULL, NULL, FILE_FORMAT_DUPLICATE);
  ImplementReader(VST,".VST")
 	LoadPictureTGA,
-	NULL);
+	NULL, NULL, FILE_FORMAT_DUPLICATE);
 #endif
 #endif
 
@@ -439,11 +456,11 @@ TImageFileHandler TIFF_H(".TIFF",
 	NULL,
 #endif
 #if SupportTIFF>=3
-	SavePictureTIFF);
+	SavePictureTIFF,
 #else
-	NULL);
+	NULL,
 #endif
-
+        NULL,FILE_FORMAT_DUPLICATE);
 #endif
 
 #ifdef SupportTXT
@@ -501,10 +518,11 @@ TImageFileHandler TIFF_H(".TIFF",
 	NULL,
  #endif
  #if SupportWPG>=3
- 	SavePictureWPG);
+ 	SavePictureWPG,
  #else
-	NULL);
+	NULL,
  #endif
+        NULL, FILE_FORMAT_256_COLORS);
 #endif
 
 
@@ -536,7 +554,7 @@ TImageFileHandler TIFF_H(".TIFF",
  //#else
 	NULL,
  //#endif
-        "2");
+        "2",FILE_FORMAT_DUPLICATE);
 #endif
 
 
@@ -568,7 +586,7 @@ TImageFileHandler TIFF_H(".TIFF",
  #else
 	NULL,
  #endif
-	NULL, FILE_FORMAT_CAP_EXIF);
+	NULL, FILE_FORMAT_CAP_EXIF|FILE_FORMAT_DUPLICATE);
 #endif
 
 
