@@ -265,12 +265,14 @@ Image *I,*OldI;
    {
    if(I->Raster!=NULL)
       {
-      if(InterlockedDecrement(&I->Raster->UsageCount)<=0) delete I->Raster;
+      if(InterlockedDecrement(&I->Raster->UsageCount)<=0)
+          delete I->Raster;
       I->Raster = NULL;
       }
    if(I->Palette!=NULL)
       {
-      if(InterlockedDecrement(&I->Palette->UsageCount)<=0) delete I->Palette;
+      if(InterlockedDecrement(&I->Palette->UsageCount)<=0)
+         delete I->Palette;
       I->Palette = NULL;
       }
    if(I->VecImage!=NULL)
