@@ -31,6 +31,11 @@
  #if defined(_MSC_VER) || defined(__BORLANDC__) || defined(ewarm)
    #define __PACKING__
  #endif
+#else
+ #if defined(PACKED)
+  #undef PACKED
+ #endif
+ #define PACKED
 #endif
 
 
