@@ -979,7 +979,7 @@ const Image *CurrentImage;
 APalette *GlobPalette = NULL;
 bool NeedLocalPalette = false;
 
-  if(Img.Raster==NULL) return(-10);
+  if(Img.Raster==NULL) return ErrEmptyRaster;
   if(Img.Raster->GetPlanes()>8) return(-11);
 
   if((f=fopen(Name,"wb"))==NULL) return(-1);
