@@ -35,6 +35,11 @@ static png_byte const mng_eXIf[5]={101,  88,  73, 102, '\0'};
 
 #if SupportPNG>=4 || SupportPNG==2
 
+#define PNG_USE_MNG	1
+#define PNG_SKIP_SIG	2
+
+static const png_byte mng_signature[8] = {138, 'M', 78, 71, 13, 10, 26, 10};
+
 static int read_user_chunk_callback(png_struct *ping, png_unknown_chunkp chunk)
 {
 		/* process eXIf or exIf chunk */
@@ -44,7 +49,7 @@ static int read_user_chunk_callback(png_struct *ping, png_unknown_chunkp chunk)
      chunk->name[3]  == 102)
   {
     Image *Img = (Image *)png_get_user_chunk_ptr(ping);
-    png_byte *s = chunk->data;
+    const png_byte *s = chunk->data;
     if(Img!=NULL && s!=NULL)
     {
       PropertyItem *PropExif = new PropertyItem("Exif",chunk->size);
@@ -54,12 +59,42 @@ static int read_user_chunk_callback(png_struct *ping, png_unknown_chunkp chunk)
         *p++ = *s++;
       Img->AttachProperty(PropExif);
     }
+    return 1;
   }
+
+	// recognized orNT
+  if(chunk->name[0] == 111 &&
+     chunk->name[1] == 114 &&
+     chunk->name[2] ==  78 &&
+     chunk->name[3] ==  84)
+  {
+    if (chunk->size != 1) return(-1);			/* Error return */
+    Image *Img = (Image *)png_get_user_chunk_ptr(ping);
+    const png_byte *s = chunk->data;
+    if(Img!=NULL && s!=NULL && s[0]<9)
+    {
+      PropertyItem *PropOrientation = new PropertyItem("orientation",1);
+      *(unsigned char *)PropOrientation->Data = s[0];
+      Img->AttachProperty(PropOrientation);
+    }
+    return(1);
+  }
+
+#if defined(PNG_MNG_FEATURES_SUPPORTED)
+  if(chunk->name[0] == 'M' &&
+     chunk->name[1] == 'H' &&
+     chunk->name[2] == 'D' &&
+     chunk->name[3] == 'R')
+  {
+    return 1;		// This ensures to skip a chunk
+  }
+#endif
+
   return 0;
 }
 
 
-void LoadFragmentPNG(FILE *F, Image *Img)
+void LoadFragmentPNG(FILE *F, Image *Img, unsigned char EnableMng)
 {
 Raster2DAbstract *Raster = NULL;
 APalette *Palette = NULL;
@@ -79,6 +114,13 @@ int i;
 
   if(!setjmp(png_jmpbuf(png_ptr)))  // if(setjmp ..)goto FINISH;	// [read_png_file] Error during init_io
   {
+#if defined(PNG_MNG_FEATURES_SUPPORTED)
+    if(EnableMng & PNG_USE_MNG)
+        png_permit_mng_features(png_ptr,PNG_ALL_MNG_FEATURES);
+#endif
+    if(EnableMng & PNG_SKIP_SIG)
+        png_set_sig_bytes(png_ptr,8);
+
     png_init_io(png_ptr, F);
 
 #if defined(PNG_UNKNOWN_CHUNKS_SUPPORTED)
@@ -91,7 +133,8 @@ int i;
     //color_type = info_ptr->color_type;
     png_byte color_type = png_get_color_type(png_ptr,info_ptr);	// TODO: Dopsat - PNG_COLOR_TYPE_PALETTE; PNG_COLOR_TYPE_RGB_ALPHA ....
 
-    int number_of_passes = png_set_interlace_handling(png_ptr);
+    //int number_of_passes = 
+        png_set_interlace_handling(png_ptr);
     png_read_update_info(png_ptr, info_ptr);
 
 	/* read file */
@@ -151,6 +194,7 @@ FINISH:
 }
 
 
+
 Image LoadPicturePNG(const char *Name)
 {
 Image Img;
@@ -160,18 +204,75 @@ FILE *f;
 
   {
     png_byte header[8];			// 8 is the maximum size that can be checked
-    fread(header, 1, 8, f);
+    if(fread(header, 1, 8, f)<8) goto FINISH;
     if(png_sig_cmp(header, 0, 8)) goto FINISH;
-    fseek(f,-8,SEEK_CUR);		// return back to a signature.
   }
 
-  LoadFragmentPNG(f,&Img);
+  LoadFragmentPNG(f,&Img,PNG_SKIP_SIG);
 
 FINISH:
   fclose(f);
 
   return(Img);		/* And we're done! */
 }
+
+
+#if defined(PNG_MNG_FEATURES_SUPPORTED)
+
+Image LoadPictureMNG(const char *Name)
+{
+Image Img;
+Image *CurImg = &Img;
+FILE *f;
+unsigned char EnableMNG = PNG_SKIP_SIG;
+png_byte header[8];			// 8 is the maximum size that can be checked
+long ChunkStart;
+
+  if((f=fopen(Name,"rb"))==NULL) return(Img);
+
+  if(fread(header, 1, 8, f)<8) goto FINISH;
+  if(!png_sig_cmp(header, 0, 8)) goto FINISH;
+  if(memcmp(mng_signature,header,8)!=0) goto FINISH;
+
+  ChunkStart = 8;
+  while(!feof(f))
+  {
+    if(fread(header, 1, 8, f)<8) goto FINISH;
+    uint32_t ChunkSize = LD_UINT32_HI(header);
+    ChunkStart += ChunkSize + 8 + 4;
+    if(!memcmp(header+4,"IHDR",4))
+    {
+      if(CurImg->Raster!=NULL)
+      {
+        CurImg->Next = new Image;
+	if(CurImg->Next==NULL) goto FINISH;
+        CurImg = CurImg->Next;
+      }
+      fseek(f,-8,SEEK_CUR);
+      LoadFragmentPNG(f, CurImg, PNG_SKIP_SIG|PNG_USE_MNG);
+      const long FilePos = ftell(f);
+      if(FilePos >= ChunkStart)
+          ChunkStart = FilePos;		// no need to seek
+      else
+          fseek(f,ChunkStart,SEEK_SET);
+    }
+    else
+      fseek(f,ChunkStart,SEEK_SET);
+  }
+
+FINISH:
+  fclose(f);
+
+  return(Img);		/* And we're done! */
+}
+
+
+	// Auxiliary handling of MNG files.
+ TImageFileHandler HANDLER_MNG(".MNG", LoadPictureMNG, NULL, NULL, FILE_FORMAT_CAP_EXIF);
+
+#endif		// PNG_MNG_FEATURES_SUPPORTED
+
+
 #endif
 
 
@@ -179,7 +280,7 @@ FINISH:
 
 int SavePicturePNG(const char *Name, const Image &Img)
 {
-  if(Img.Raster==NULL) return(-10);
+  if(Img.Raster==NULL) return ErrEmptyRaster;
 
 	/* create file */
   FILE *fp = fopen(Name, "wb");
@@ -319,7 +420,7 @@ int SavePicturePNG(const char *Name, const Image &Img)
 
   if(!Img.Properties.isEmpty())
   {
-    for(int i=0; i<Img.Properties.PropCount; i++)
+    for(unsigned i=0; i<Img.Properties.PropCount; i++)
     {
       PropertyItem *Prop = Img.Properties.pProperties[i];
       if(Prop!=NULL && Prop->Data!=NULL && Prop->DataSize>0 && Prop->Name=="Exif")
