@@ -25,7 +25,7 @@
 #include "stringa.h"
 #include "lists.h"
 
-#include "images/raster.h"
+#include "raster.h"
 #include "wp2latex.h"
 #include "struct.h"
 #include "cp_lib/cptran.h"
@@ -39,7 +39,7 @@ static const char *Parts[8] = {
  "subsubsection", "paragraph", "subparagraph","" };
 
 #ifndef FINAL
-/*This procedure isn't normally called. It can be used for exploration of new objects*/
+/**This procedure isn't normally called. It can be used for exploration of new objects*/
 void CrackObject(TconvertedPass1 *cq, uint32_t end_of_code)
 {
 FILE *txt;
@@ -202,9 +202,10 @@ unsigned i;
  
  switch(Attr)
  {
-   case Cyr_Font: Cyrillic = true; break;
-   case Heb_Font: cjHebrew = true; break;
-   case Georgia_Font: mxedruli = true; break;
+   case Cyr_Font: Cyrillic=true; break;
+   case Heb_Font: cjHebrew=true; break;
+   case Georgia_Font: mxedruli=true; break;
+   case Arabic_Font: arabtex=true; break;
  }
 
 return;
@@ -279,17 +280,21 @@ string s;
  if(!s.isEmpty()) fputs(s(),cq->strip);
 
  if(attr_num==Heb_Font && cq->Font==FONT_HEBREW)
-   {
+ {
    cq->Font = FONT_NORMAL;
-   }
+ }
  if(attr_num==Cyr_Font && cq->Font==FONT_CYRILLIC)
-   {
+ {
    cq->Font = FONT_NORMAL;
-   }
+ }
  if(attr_num==Georgia_Font && cq->Font==FONT_GEORGIA)
-   {
+ {
    cq->Font = FONT_NORMAL;
-   }
+ }
+ if(attr_num==Arabic_Font && cq->Font==FONT_ARABIC)
+ {
+   cq->Font = FONT_NORMAL;
+ }
 
 return;
 }
@@ -911,9 +916,17 @@ void CharacterStr(TconvertedPass1 *cq, const char *LatexCode)
                  {
 		 AttrOff(cq,Georgia_Font);
                  }
+               if(cq->Font==FONT_ARABIC)
+                 {
+		 AttrOff(cq,Arabic_Font);
+                 }
 	       cq->Font = FONT_NORMAL;
 	       fprintf(cq->strip, "\\rm ");
 	       break;
+         case FONT_ARABIC:
+	       AttrOn(cq->attr,Arabic_Font);
+	       cq->Font = FONT_ARABIC;
+	       break;
 	 case FONT_CYRILLIC:		//cyrillic font
 	       AttrOn(cq->attr,Cyr_Font);
 	       cq->Font = FONT_CYRILLIC;
@@ -2490,7 +2503,7 @@ static const char *PrevFeature = NULL;
   PrevFeature = Feature;
 
   perc.Hide();
-  fprintf(err, _("\nNote: Please send me this %s file for WP2LaTeX improvment, unimplemented feature \"%s\"."),Type,Feature);
+  fprintf(err, _("\nNote: Please send me this %s file for WP2LaTeX improvement, unimplemented feature \"%s\"."),Type,Feature);
 }
 #endif
 
