@@ -25,7 +25,7 @@
 
 #include "wp2latex.h"
 #include "cp_lib/cptran.h"
-#include "images/raster.h"
+#include "raster.h"
 #include "cp_lib/out_dir/mtef.trn"
 
 
