@@ -235,6 +235,12 @@ if(c=='<')	//Handle HTML tag
 		}
 	     }
 	  }
+        if(Value.isEmpty() && c=='>' && Attribute=='/')
+        {
+          if(by==XML_closedtag) by=XML_closedclosetag;
+          if(by==XML_tag) by=XML_closedtag;
+          break;
+        }
 	TAG_Args.Add(Attribute(),Value());
 	if(c=='>') break;
 	}
