@@ -331,6 +331,7 @@ string TeX_RelativeFigDir;
     if(Columns==2)  fprintf(this->LaTeX, ",twocolumn");
     if(Columns>2)   fprintf(this->LaTeX, ",multicol");
     if(EndNotes>=1) fprintf(this->LaTeX, ",endnotes");
+    if(arabtex>=1)  fprintf(this->LaTeX, ",arabtext");
     if(Cyrillic>=1) fprintf(this->LaTeX, ",cyrillic");
     if(cjHebrew>=1) fprintf(this->LaTeX, ",cjhebrew");
     if(mxedruli>=1) fprintf(this->LaTeX, ",mxedruli");
@@ -388,6 +389,7 @@ string TeX_RelativeFigDir;
 		break;
 	}
     if(colors>=1)   UsePackage("color");
+    if(arabtex>=1)  UsePackage("arabtex");
     if(Cyrillic>=1) UsePackage("cyrillic");
     if(cjHebrew>=1) UsePackage("cjhebrew");
     if(mxedruli>=1) UsePackage("mxedruli");
